@@ -5,7 +5,7 @@ CLIENT_ID = getattr(settings, 'MERCADOPAGO_CLIENT_ID', '')
 CLIENT_SECRET = getattr(settings, 'MERCADOPAGO_CLIENT_SECRET', '')
 PUBLIC_KEY = getattr(settings, 'MERCADOPAGO_PUBLIC_KEY', '')
 ACCESS_TOKEN = getattr(settings, 'MERCADOPAGO_ACCESS_TOKEN', '')
-PLATFORM_ID = getattr(settings, 'MERCADOPAGO_PLATFORM_ID', '')
+PLATFORM_ID = getattr(settings, 'MERCADOPAGO_PLATFORM_ID', 'dev_abf6a3c4d0ee11eab4a00242ac130004')
 PAYMENT_MODEL = getattr(settings, 'MERCADOPAGO_PAYMENT_MODEL', '')
 PAID_USECASE = getattr(settings, 'MERCADOPAGO_PAID_USECASE', '')
 REJECTED_USECASE = getattr(settings, 'MERCADOPAGO_REJECTED_USECASE', '')
